---
title: Download - Upload
---
# Download / Upload

The next session focuses on large repositories of digital text, so-called *shadow libraries*, that are technologically organised around actions of download and upload from and to server infrastructures. The session introduces learners to:

- a) workflows used in digital text sharing, collection-building and collection-maintaining;
- b) three shadow libraries: [Library Genesis](https://gen.lib.rus.ec), [Aaaaarg](https://aaaaarg.fail) and [Memory of the World](https://library.memoryoftheworld.org), and the legal pressures they face;
- c) politicising interventions that articulate practices of digital text sharing as massive, collective and commoning.

The goal is to get learners acquainted with three examples of shadow libraries that are created by communities of contributors and benefit a broader public. The fact that they maintain centralised repositories and they do not obfuscate their existence entails a need for an articulation of politics of collective disobedience and practice of collective custodianship. This session covers a lot of practical ground and different debates, requiring more time than the remaining sessions in this topic. You can break these segments up into separate chunks of time or re-organise them into one longer workshop. Depending on the number of participants and their skills, the time needed for each segments might vary from what is proposed here.

## Segment 1: Download / Upload

Duration: 90 minutes

Methods: learning by doing, learners have to use their own computers to complete the tasks.

Goal: In this practical segment, the learners will acquire first-hand knowledge of how to download and upload, create collections and maintain collections on Library Genesis, Aaaaarg and Memory of the World.

Task 1:
- download from Library Genesis,
- [upload to Library Genesis](https://libgen.is/librarian/) (uname:genesis, passwd: upload),
- [upload using LibGen Desktop](https://wiki.mhut.org/software:libgen_desktop)

Task 2:
- login to Aaaaarg,
- download from Aaaaarg,
- add a [request for an item](https://aaaaarg.fail/thing/add) and upload that item,
- start a [new collection](https://aaaaarg.fail/collection/add), add items to your collection (go to an item -> collections column -> 'sort into collection')
- start a [discussion](https://aaaaarg.fail/talk/add), add to an existing discussion

Task 3:
- download from Memory of the World,
- install [Calibre](https://calibre-ebook.com/download), add an item to Calibre, edit its metadata (right-click -> edit metadata)
- for the advanced learners: install in command line (> pip3 install accorder) and test the accorder tool, use the local version of the collection HTML file created by accorder

Discussion: Learners should summarise the differences between the three shadow libraries, particularly focusing on public accessibility, how the work of uploading items is organised, how the bibliographic metadata is handled and what type of engagement of the community of uploaders and the community of downloaders they suggest.

## Segment 2: Library Genesis

Duration: 90 minutes

Methodology: reading & discussion, analysis of the interface

Goal: In this segment, the learners will get acquainted with the history, community and communication infrastructure of Library Genesis. Library Genesis has emerged as the largest shadow library after the collection of Gigapedia/Library.nu (shut down under legal pressure) was merged into its collection, and is presently the largest of shadow libraries by some margin, holding over 2 million titles. Library Genesis's code, database and collection are all downloadable, and there is a number of mirrors providing alternative access to some or all of its holdings.

The segment starts by discussing two texts documenting the history and operation of Library Genesis that the learners are asked to read in advance. They are then given time to analyse the segments of the Library Genesis website and [the bulletin board forum of the Library Genesis](https://forum.mhut.org/viewforum.php?f=6).

The aim is to get learners to see how the politics of community is implemented and how it follows from the technical aspects of the Library Genesis.

### References

Tenen, D. and Foxman, M. (2014)' Book Piracy as Peer Preservation'. *Computational Culture* [online] (4). available from <http://computationalculture.net/book-piracy-as-peer-preservation/> [28 November 2019]

Bodó, Balázs. "The Genesis of Library Genesis: The Birth of a Global Scholarly Shadow Library." In Shadow Libraries: Access to Knowledge in Global Higher Education, by Joe Karaganis, 25–51. Cambridge, MA: MIT Press, 2018.


## Segment 3: Aaaaarg & Memory of the World - legal cases and politicisation

Duration: 90 minutes

Methodology: advance reading and discussion guided through questions

The learners are asked in advance to read up on Aaron Swartz, on Elsevier v Library Genesis case, and read the texts *Aaaaarghhhhh, a Lawsuit!*, Custodians.online letter and 'System of a Takedown'. The discussion should first start from going back to the shutdown of Gigapedia/Library.nu that led to the ascendancy of Library Genesis. Learners are asked to summarise the aspects of legal cases around shadow libraries and reflect on the larger context of struggles over copyright and intellectual property that these are part of. They are asked to reflect on the denial of access and limitation of the mission of public libraries, and the complementarity of shadow libraries and public libraries.

The discussion should then focus on implications of the three shadow libraries Library Genesis, Aaaaarg and Memory of the World. They operate in plain sight, have large communities of contributors and maintain largely centralised repositories - what strategies do they use to diminish legal vulnerability and what arguments do they use to publicly articulate their work? What role does in those strategies play the societal institutions of production and dissemination of knowledge with their missions and processes — for instance, public library and its mission of providing decommodified access to all literature to all of the society.

To conclude, the discussion should focus on the Custodians.online letter, to analyse the main points around the inversion of property form into a commons, collective disobedience and response to the larger context of socio-economic crisis and the crisis of public access to knowledge.

### References

![](bib:2d619c79-0e37-455d-ab83-cf02b6cf845c)

![](bib:857136f9-efe1-4ebe-a65e-e3ff0aaa22b6)

![](bib:d17e1db9-c2d3-4512-a72e-854900e97cbf)

![Custodians.online. “In Solidarity with Library Genesis and Sci-Hub.” http://custodians.online, November 30, 2015. 
](bib:edd7b776-a2cd-4801-b5e3-0c427ced2c25)

![*Aaaaarghhhhh, a Lawsuit!* (2016) available from <https://www.gofundme.com/f/aaaaarg> [28 November 2019]](bib:b542e073-9d2f-45f7-a21f-14ff6b304ee2)

![](bib:f37521fa-8644-4ffa-b6b7-e47f94577e1d)