---
title: Fostering equity and diversity in the hacker/maker scene
has_sessions: diversifingyournarratives, mappingtheunspoken, etextilesasatooltodecolonizeelectronics
---


### Introduction
Pirate Care is an emergent phenomenon where a growing number of initiatives related to health and care find themselves inhabiting grey regulatory zones, which pop-up more and more often. At the same time, a lot of projects born within the maker community, intersecting with hacker culture, are using open source and digital technologies to co-create solutions in situations where public or private institutions are idle. 

These initiatives share the vision that technology can be redirected toward new purposes and grounded to sustain different narratives, in which citizen perceive themselves as “contributors” rather than “consumers” of technology and science. Actively countering the deterministic trends of both these domains, the makers’ approach enhances the relation with the world through concrete material engagement, by challenging normative views of knowledge production and expertise.

Hackers and Makers ideally embrace an egalitarian vision of making, but very often, in practice, we see that at the level of access and opportunities such values lack a concrete application, because making always takes place in spaces and times influenced by institutional, societal, and individual histories.

This contribution to the Pirate Care Syllabus is a tentative effort to start a process of sharing resources and practices to recognise, on one side, how science and technology have been playing a leading role in the toolbox of the powerful, by limiting the self-empowerment of historically marginalized communities and/or reinforcing existing values and biased ideologies. On the other side, this tpoic hopes to spread a set of resources and tools within the maker community, to help it avoid the same mistakes other disciplines have done in the past and to bring awareness on the different opportunities unfolding with a more diverse approach.  

From an activist perspective, the word “decolonising” is becoming more and more useful for naming and understanding broader implications of phenomena that have a long history in shaping the social, much beyond physical borders. As [Beatrice Martini](https://beatricemartini.it/blog/decolonizing-technology-reading-list/) highlights in the introduction of her reading list:

> ”One example of this kind of ‘borderless colonial’ phenomenon comes from digital technology. While many technical innovations are asserted as universally positive and beneficial to communities worldwide, beyond borders and across cultures, a closer analysis of who holds the power, who has agency, and whose interests are promoted, can often reveal a very different picture.” <

Therefore we need to pay deeper attention to what constitutes a "community" and how the unequal distribution of agency impacts the way learning and making can take shape across the borders of gender, race, and class.

In recent years, the science and tech community has been taking a self-reflexive look at the role these fields of expertise played historically and presently in society, to prevent perpetuating mistakes and address patterns of exclusion. In the same way, this syllabus topic is an invitation for the maker/hacker community to embed this perspective in our practices because even science, which is first of all a method, but soon became an industry and a dispositive of power, has proved to be harmful, if not guided by ethical principles of equity.  

As makers and hackers, developing a perspective look at our places and practices means being aware that people can simultaneously experience privilege and oppression depending on the context. The image below shows the framework by the **Intersectionality** concept which was coined by lawyer and civil rights advocate Kimberlé W. Crenshaw in 1989, and rooted in the research and activism of women of color, extending back to Sojourner Truth’s [“Ain’t I a Woman”](https://www.nps.gov/articles/sojourner-truth.htm) speech in 1851. It reveals how the most pressing social justice issues can't be productively addressed through traditional frameworks or by explaining these problems as the product of just one axis of exclusion. We need to take a deeper look at the interconnected factors that influence power, privilege and oppression and the intersectional approach helps focus on systems and contexts to be decolonised. 

In the makerspaces, hacking and fablab context, this means considering who is impacted (or not) by the work that we do, whose voices are missing, questioning assumptions made in activities, while we engage the community or design our educational programs.

Below, you will find a series of publications, links and media to explore different points of view addressing the issue.

This topic has (so far) three sessions, where I proposed 3 possible activities to inspire action:

- ![](session:diversifingyournarratives)
- ![](session:mappingtheunspoken)
- ![](session:etextilesasatooltodecolonizeelectronics)


![Intersectionality Spectrum](https://www.awis.org/wp-content/uploads/intersectionality-sources-cited.jpg)

### Reading Resources

#### Books


- [Zeros and ones : Digital Women and the New Technoculture - Sadie Plant](https://library.memoryoftheworld.org/#/book/ee635b88-6f68-4bc8-b256-a69ca7f3f2ac) 

- [The fabric of interface - Stephen Monteiro](https://memoryoftheworld.org/#/book/0ec6d5d1-9445-483b-bdc0-bf17ce2084ae)
- [Inferior - How Science Got Women Wrong and the New Research That's Rewriting the Story - Angela Saini](http://93.174.95.29/_ads/94A97B61A7AFF6E81182B02FDFF77242)
- [Sciences from below - Sandra Harding](http://93.174.95.29/_ads/C516418F5F4A0EBA9689686DE768B2A8)
- [Situated Knowledges: The Science Question in Feminism and the Privilege of Partial Perspectives](http://93.174.95.29/_ads/9437CB2EC4770A4DA0F4E7F5DBCC1B6F)
- [Rebelling with care - Exploring open technologies for commoning healthcare - AA.VV](https://www.researchgate.net/publication/335911369_Rebelling_with_Care_Exploring_open_technologies_for_commoning_healthcare)
- [Critical Maker Reader - AA.VV](https://networkcultures.org/blog/publication/the-critical-makers-reader-unlearning-technology/)
- [Hacking Diversity: The Politics of Inclusion in Open Technology Cultures - Christina Dunbar-Hester](http://93.174.95.29/_ads/199259802A1BC7276BEA9EB8E3DC0127) 
- [The Additivism Manifesto & Cookbook](https://additivism.org/)

---

#### Papers
- [Global Gender Gap Report](hhttps://en.wikipedia.org/wiki/Global_Gender_Gap_Report)
- [Maker Cultures and the Prospects for Technological Action](https://link.springer.com/article/10.1007%2Fs11948-016-9796-8)  
- [The gender-based digital divide in maker culture: features, challenges and possible solutions]( https://www.cairn.info/revue-journal-of-innovation-economics-2018-3-page-147.htm#) 
- [Feminist and women's hackerspaces](https://geekfeminism.wikia.org/wiki/Feminist_and_women%27s_hackerspaces) 

- [Feminist Hackerspaces as Sites for Feminist Design](https://dl.acm.org/citation.cfm?id=2764771) 
- [Legacies of craft and the centrality of failure in a mother-operated hackerspace](https://www.semanticscholar.org/paper/Legacies-of-craft-and-the-centrality-of-failure-in-Rosner-Fox/98428db4cb533666b615a5527ab356af32ec0679)   
- [Breaking Gender Code: Hackathons, Gender, and the Social Dynamics of Competitive Creation](http://hackathon-workshop-2018.com/Sian%20JM%20Brooke.pdf) 
- [How stereotypes impair women’s careers in science](http://www.ereuben.net/research/StereotypesWomensCareer.pdf)
- [How Race & Gender Interact To Shape Inequality](https://decolonizeallthethings.com/2019/03/19/how-race-gender-interact-to-shape-inequality/) 
- [A Longitudinal Study of Equity-Oriented STEM-Rich Making Among Youth From Historically Marginalized Communities ](https://journals.sagepub.com/doi/10.3102/0002831218758668)
- [The gender-based digital divide in maker culture: features, challenges and possible solutions](https://www.cairn.info/revue-journal-of-innovation-economics-2018-3-page-147.htm) 
- [Queer Science: LGBT Scientists Discuss Coming Out at Work](https://www.bitchmedia.org/post/queer-science-lgbt-scientists-discuss-coming-out-at-work)
- [Dismantling Feminist Biology through the Design of eTextiles](https://figshare.com/articles/Dismantling_feminist_biology_through_the_design_of_etextiles/7855805/1)

- [Electronic Textiles as Disruptive Designs: Supporting and Challenging Maker Activities in Schools](https://www.researchgate.net/publication/277928108_Electronic_Textiles_as_Disruptive_Designs_Supporting_and_Challenging_Maker_Activities_in_Schools) 
- [Rebelling with care - Exploring open technologies for commoning healthcare](https://www.researchgate.net/publication/335911369_Rebelling_with_Care_Exploring_open_technologies_for_commoning_healthcare)
- [Gender: Integrated report of findings - FLOSS](https://www.researchgate.net/publication/264799720_FLOSSPOLS_Deliverable_D_16_Gender_Integrated_Report_of_Findings)
---

#### Articles

[Gender Equality ≠ Gender Neutrality](https://www.genderscilab.org/blog/gender-equality-does-not-equal-gender-neutrality)

On decolonizing as a concept
- [We need a decolonized not a diverse education](http://harlot.media/articles/1058/we-need-a-decolonized-not-a-diverse-education)
- [Digital Colonialism, the internet as a tool of cultural hegemony](https://web.archive.org/web/20190316002911/http://www.knowledgecommons.in/brasil/en/whats-wrong-with-current-internet-governance/digital-colonialism-the-internet-as-a-tool-of-cultural-hegemony/) 
- [Data Colonialism - Tech for social change](https://modelviewculture.com/pieces/data-colonialism-critiquing-consent-and-control-in-tech-for-social-change) 


On gender diversity 

![What happened to Women in computer science?](https://hackernoon.com/hn-images/1*mVqtLT4yiwjgZovRSNvTkw.png)

- [Black women physicists In the Wake](https://medium.com/@chanda/black-women-physicists-in-the-wake-ebf2cdeadb1a)

- [Ballarat Hackerspace giving women a safe space to follow their tech interests](https://www.thecourier.com.au/story/4726305/women-take-on-tech/) 

* [Researcher reveals how “Computer Geeks” replaced “Computer Girls”](https://gender.stanford.edu/news-publications/gender-news/researcher-reveals-how-computer-geeks-replaced-computer-girls)

* [Women pioneered computer programming. Then men took their industry over](https://timeline.com/women-pioneered-computer-programming-then-men-took-their-industry-over-c2959b822523)

On horizontality

* [The Tyranny of Structurelessness](https://www.jacobinmag.com/2019/09/tyranny-structurelessness-jo-freeman-consciousness-raising-women-liberation-feminism)

---

#### Links
* [D.A.T.S. Scientific Ethics Statement & Reading Guide](https://decolonizeallthescience.com/) 
* [Technology Colonialism](https://modelviewculture.com/pieces/technology-colonialism ) 
* [Decolonisation is not a metaphor](https://www.researchgate.net/publication/277992187_Decolonization_Is_Not_a_Metaphor)
* [Timeline of geek feminism](https://geekfeminism.wikia.org/wiki/Timeline_of_geek_feminism) 
* [Timeline of women in computing ](https://rarlindseysmash.com/WiCVis/index.html) 
* [Computer Grrrls - Exhibition](https://gaite-lyrique.net/en/event/computer-grrrls)
 * [Computer Grrrls - Leaflet](https://gaite-lyrique.net/storage/2019/04/04/computer-grrrls-exhibition-leaflet-english.pdf)
 * [Google’s Ideological Echo Chamber](https://assets.documentcloud.org/documents/3914586/Googles-Ideological-Echo-Chamber.pdf)
 * [Decolonizing Design](http://www.decolonisingdesign.com/statements/2016/editorial/)

---
#### Podcasts

-- [When Women stopped coding](https://www.npr.org/sections/money/2014/10/17/356944145/episode-576-when-women-stopped-coding")

---

#### Videos
-- [Inclusion & Exclusion collection on Hack_curio ](https://hackcur.io/category/inclusions-exclusions/)

---

Wanna contribute? Drop me a message on twitter @zoescope