---
title: Introduction to Pirate Care
has_sessions: whatiscare, problemswithcare, whatcanpiracybe
---

This Introduction gives an overview of the main questions and concerns voiced by the expression ‘pirate care’, which also the gathering principle for bringing together the different knowledges, techniques and tools shared in this collective syllabus.

Pirate Care primarily considers the assumption that we live in a time in which care, understood as a political and collective capacity of society, is becoming increasingly defunded, discouraged and criminalised. Neoliberal policies have for the last two decades re-organised the basic care provisions that were previously considered cornerstones of democratic life - healthcare, housing, access to knowledge, right to asylum, freedom of mobility, social benefits, etc. - turning them into tools for surveilling, excluding and punishing the most vulnerable. The name Pirate Care refers to those initiatives that have emerged in opposition to such political climate by self-organising technologically-enabled care & solidarity networks. 

# On the concept of Pirate Care

Punitive neoliberalism (Davies, 2016)[^5] has been repurposing, rather than dismantling, welfare state provisions such as healthcare, income support, housing and education (Cooper, 2017: 314)[^3]. This mutation is reintroducing 'poor laws' of a colonial flavour, deepening the lines of discrimination between citizens and non-citizens (Mitropoulos, 2012: 27)[^13], and reframing the family unit as the sole bearer of responsibility for dependants.

Against this background of institutionalised *'negligence'* (Harney & Moten, 2013: 31)[^12], a growing wave of mobilizations around care can be witnessed across a number of diverse examples: the recent Docs Not Cops campaign in the UK, refusing to carry out documents checks on migrant patients; migrant-rescue boats (such as those operated by Sea-Watch) that defy the criminalization of NGOs active in the Mediterranean; and the growing resistance to homelessness via the reappropriation of houses left empty by speculators (like PAH in Spain); the defiance of legislation making  homelessness illegal (such as Hungary's reform of October 2018) or municipal decrees criminalizing helping out in public space (e.g. Food Not Bombs' volunteers arrested in 2017).

On the other hand, we can see initiatives experimenting with care as collective political practices have to operate in the narrow grey zones left open between different technologies, institutions and laws in an age some fear is heading towards 'total bureaucratization' (Graeber, 2015: 30)[^8]. For instance, in Greece, where the bureaucratic measures imposed by the Troika decimated public services, a growing number of grassroots clinics set up by the Solidarity Movement have responded by providing medical attention to those without a private insurance. In Italy, groups of parents without recourse to public childcare are organizing their own pirate kindergartens (Soprasotto), reviving a feminist tradition first experimented with in the 1970s. In Spain, the feminist collective GynePunk developed a biolab toolkit for emergency gynaecological care, to allow all those excluded from the reproductive medical services  -  such as trans or queer women, drug users and sex workers  - to perform basic checks on their own bodily fluids. Elsewhere, the collective Women on Waves delivers abortion pills from boats harboured in international waters - and more recently, via drones - to women in countries where this option is illegal.

Thus pirate care, seen in the light of these processes - choosing illegality or existing in the grey areas of the law in order to organize solidarity - takes on a double meaning: Care as Piracy and Piracy as Care (Graziano, 2018)[^9].

There is a need to revisit piracy and its philosophical implications - such as sharing, openness, decentralization, free access to knowledge and tools (Hall, 2016)[^11] - in the light of transformations in access to social goods brought about by digital networks. It is important to bring into focus the modes of intervention and political struggle that collectivise access to welfare provisions as acts of custodianship (Custodians.online, 2015)[^4] and commoning (Caffentzis & Federici, 2014)[^2]. As international networks of tinkerers and hackers are re-imagining their terrain of intervention, it becomes vital to experiment with a changed conceptual framework that speaks of the importance of the digital realm as a battlefield for the re-appropriation of the means not only of production, but increasingly, of social reproduction (Gutiérrez Aguilar et al., 2016)[^10]. More broadly, media representations of these dynamics - for example in experimental visual arts and cinema - are of key importance. Bringing the idea of pirate ethics into resonance with contemporary modes of care thus invites different ways of imagining a paradigm change, sometimes occupying tricky positions vis-à-vis the law and the status quo.

The present moment requires a non-oppositional and nuanced approach to the mutual implications of care and technology (Mol et al., 2010: 14)[^14], stretching the perimeters of both. And so, while the seminal definition of care distilled by Joan Tronto and Berenice Fisher sees it as 'everything that we do to maintain, continue, and repair "our world" so that we can live in it as well as possible' (Tronto & Fisher, 1990: 40)[^7], contemporary feminist materialist scholars such as Maria Puig de La Bellacasa feel the need to modify these parameters to include 'relations [that] maintain and repair a world so that humans and non-humans can live in it as well as possible in a complex life-sustaining web' (Puig de La Bellacasa, 2017: 97)[^6]. It is in this spirit that we propose to examine how can we learn to compose (Stengers, 2015)[^15] answers to crises across a range of social domains, and alongside technologies and care practices.

If confronting the unequal provision of care has long been a focus of progressive political organising, today’s hyper-interconnected and heavily exhausted world calls for radical approaches and tools for militant caring that, while might not provide readymade, one-size-fits-all answers, might allow us to prefigure different forms of co-inhabitation on this planet. 
Pirate Care is therefore interested in researching how to re-conceive care provisions across the tensions between autonomous organising and state institutions, between insurgent politics and commoning, and between holistic and scientific methods.


[^2]: Caffentzis, G. and Federici, S., 2014. 'Commons against and beyond capitalism'. Community Development Journal, 49(suppl_1), pp.i92-i105.

[^3]: Cooper, M., 2017. Family values: Between neoliberalism and the new social conservatism. MIT Press.

[^4]: Custodians Online, 2015. 'In solidarity with Library Genesis and Sci-Hub', 30th November, http://custodians.online/.

[^5]: Davies, W., 2016. 'The new neoliberalism'. New Left Review (101), 121--134

[^6]: de La Bellacasa, M.P., 2017. Matters of care: Speculative ethics in more than human worlds. University of Minnesota Press.

[^7]: Fisher, B. and J. C. Tronto, 1990. 'Toward a feminist theory of care', in Circles of Care: Work and identity in women's lives, eds. Emily K. Abel and Margaret K. Nelson, Albany: SUNY Press.

[^8]: Graeber, D., 2015. The utopia of rules: On technology, stupidity, and the secret joys of bureaucracy_. Melville House.

[^9]: Graziano, V. 2018. 'Pirate Care - How do we imagine the health care for the future we want?', Medium, 5th October https://medium.com/dsi4eu/pirate-care-how-do-we-imagine-the-health-care-for-the-future-we-want-fa7f71a7a21.

[^10]: Gutiérrez Aguilar R., Linsalata L. and M.L.N. Trujillo, 2016. 'Producing the common and reproducing life: Keys towards rethinking the Political.' in Social Sciences for an Other Politics, ed. A. Dinerstein, Palgrave Macmillan.

[^11]: Hall, G., 2016. Pirate philosophy: for a digital posthumanities. MIT Press.

[^12]: Harney, S. and Moten, F., 2013. The undercommons: Fugitive planning and black study, Minor Compositions.

[^13]: Mitropoulos, A., 2012. Contract & contagion: From biopolitics to oikonomia. Minor Compositions.

[^14]: Mol, A., Moser, I. and Pols, J. eds., 2015. Care in practice: On tinkering in clinics, homes and farms. transcript Verlag.

[^15]: Stengers, I. (2015) In catastrophic times: Resisting the coming barbarism. Open Humanities Press.


# A Pirate Care Syllabus: why, how and with whom?

A point of entry into the practices of pirate care for us is pedagogy - how these practices can be taught and studied with fellow pirate care practitioners, activist communities and beyond. To that end, we have started building a collaborative online syllabus on Pirate Care, covering each practice through a dedicated topic and a number of sessions that are concrete proposals for learning. Our vision that such a syllabus is technologically architected so that it can be easily adapted to different contexts and activated by interested groups elsewhere to collectively learn from it. 

This syllabus was inspired by the recent phenomenon of crowdsourced online syllabi generated within social justice movements (see below). In November 2019 we held a writing retreat to create the first version of a pirate care syllabus. We were hosted by the cultural centre [Drugo More](http://drugo-more.hr/en/) and supported via the Rijeka European Capital of Culture 2020 programme. The contributors were: Laura Benítez Valero, Emina Bužinkić, Rasmus Fleischer, Maddalena Fragnito, Valeria Graziano, Mary Maggic, Iva Marčetić, Marcell Mars, Tomislav Medak, Memory of the World, Power Makes Us Sick (PMS), Zoe Romano, Ivory Tuesday, Ana Vilenica. 

The different topics covered were written by practitioners active across a number of pressing issues, including: feminist approaches to reproductive healthcare; autonomous mental health support; trans health and well-being; free access to knowledge; housing struggles; collective childcare; the right to free mobility; migrant solidarity; community safety and anti-racist organising.

We worked through group discussions; sharing of texts, materials and zines; presentations and workshops (including one on how to use gitlab and one on making baskets with pine needles); informal conversations, cooking for each other and walking together; playing karaoke and telepathy games; mutual feedback and friendship that carried on in the following months. New sessions are to be developed in Vienna with new collaborators during a residency at *studio das weisse haus* in cooperation with Kunsthalle Wien (March-April 2020). 

Work on syllabus is the extension of the [Memory of the World](https://library.memoryoftheworld.org/#/books/) shadow library and it espouses a certain technopolitics. We have developed an online publishing framework allowing collaborative writing, remixing and maintaining of the syllabus. We want the syllabus to be ready for easy preservation and come integrated with a well-maintained and catalogued collection of learning materials. To achieve this, our syllabus is built from plaintext documents that are written in a very simple and human-readable Markdown markup language, rendered into a static HTML website that doesn’t require a resource-intensive and easily breakable database system, and which keeps its files on a git version control system that allows collaborative writing and easy forking to create new versions. Such a syllabus can be then equally hosted on an internet server and used/shared offline from a USB stick.

In summer 2020, the Pirate Care Syllabus will be activated through an exhibition (June) and a summer camp (September) as part of Rijeka European Capital of Culture 2020 (Croatia).

# Collective statements

These below are some shared statements that emerged from the collective process building the first version of the syllabus:

* Ours is inevitably as a partial group, who came together in a supportive context, but who also faced a limited amount of time in co-presence. The contributors did not all know each other in advance and we do not form a stable community in the everyday. Our composition reflects the limits of the resources, relationships and awareness available to the organisers and the participants, as well as their commitments and stakes. We do not represent others nor share a unified political position; however we worked in such a way as to allow differences to remain generative and inform different topics and sessions in the syllabus, which were therefore not ‘unified’ in style.  
*     
* Many issues are under-represented here. We started to write from our practices and from our situated knowledges and experiences. We hope that the syllabus might become a useful tool for others who might want to add new topics and perspectives to it in the future.    
*     
* Language is a technology that needs to be decolonized. While we strive to write for accessibility, we are conscious of our educational and professional biases in using and modulating the way we use language. We are aware our common language was English and that this leaves out a number of other possibilities of communication. Whenever we felt this was important, we have included some references in other languages in the first version of the syllabus.
*     
* Writing for an online imagined reader is a challenging task because it does not allow to speak to specific persons and collectives immersed in actual circumstances. The question ‘who are we speaking with’ in the case of an online syllabus becomes very tricky to answer. Our approach has been to write as if to friends with whom we share key ethical and political values, but who might not be familiar yet with the specific crafts of care we practice or with the background data and knowledge that inform our actions.    
*     
* The specificity and partiality of our composition is also reflected on the resources we reference. Most texts are from Western academe or activist spaces. We are committed to address this and learn from others in an ongoing efforts to diversify our sources and imaginaries.   
*     
* We encourage everyone to freely use this syllabus to learn and organise processes of learning and to freely adapt, rewrite and expand it to reflect their own experience and serve their own pedagogies. We do not believe that the current licence system supports the world we want to live in, and that is a world in which knowledge is not privatized. However, the current system automatically copyrights our work, so we state here that all the original writing contained in this syllabus is under CC0 1.0 Universal (CC0 1.0), Public Domain Dedication, No Copyright. This means that: “The person who associated a work with this deed has dedicated the work to the public domain by waiving all of his or her rights to the work worldwide under copyright law, including all related and neighboring rights, to the extent allowed by law. You can copy, modify, distribute and perform the work, even for commercial purposes, all without asking permission.” https://creativecommons.org/publicdomain/zero/1.0/
* 
* We encourage you to get in touch, to learn together, to organise, assist and act collectively. Lets mirror each other in solidarity.
    
  *  infor@pirate.care*


# Online syllabi linked with social justice movements

In putting together a collective pirate care syllabus, open to new contributions and remixes, we were inspired, alongside many other popular education initiatives, by the recent phenomenon of hashtag syllabi (or, simply, #syllabi) connected with social justice movements, many of which are U.S. based and emerging from anti-racist struggles led by Black American and feminist activists.  

For an introduction to the phenomenon online syllabi, see the text: ‘Learning from the #Syllabus, Graziano, V., Mars, M. and Medak, T., in State Machines: Reflections and Actions at the Edge of Digital Citizenship, Finance, and Art. Institute of Network Cultures, 2019
http://www.statemachines.eu/books/state-machines-reflections-and-actions-at-the-edge-of-digital-citizenship-finance-and-art/


Here is a few examples of such crowdsourced online syllabi:

In August 2014, Michael Brown, an 18 year old boy living in Ferguson, Missouri, was shot to death by police officer Darren Wilson. Soon after this episode, as the civil protests denouncing police brutality and institutional racism begun to mount across the US, Dr. Marcia Chatelain, Associate Professor of History and African American Studies at Georgetown University, launched an online call urging other academics and teachers 'to devote the first day of class to hold a conversation about Ferguson' and 'to recommend texts, collaborate on conversation starters, and inspire dialogue about some aspect of the Ferguson crisis’ (Chatelain, 2014). Chatelain did so using the hashtag #FergusonSyllabus.

Chatelain, M. (2014). “Teaching the #FergusonSyllabus.” Dissent Magazine, November 28. https://www.dissentmagazine.org/blog/teaching-ferguson-syllabus

Chatelain, M. (2014b). “How to Teach Kids About What’s Happening in Ferguson.” The Atlantic, August 25. https://www.theatlantic.com/education/archive/2014/08/how-to-teach-kids-about-whats-happening-in-ferguson/379049/


In August 2014, using the hashtag #gamergate to coordinate, groups of users on 4Chan, 8Chan, Twitter and Reddit instigated a misogynistic harassment campaign against game developers Zoë Quinn and Brianna Wu, media critic Anita Sarkeesian, as well as a number of other female and feminist game producers, journalists and critics. In the following weeks, The New Inquiry editors and contributors compiled a reading list and issued a call for suggestions for their TNI Syllabus: Gaming and Feminism (The New Inquiry Editorial Collective, 2014).
https://thenewinquiry.com/tni-syllabus-gaming-and-feminism/


In June 2015, Donald Trump announced his candidacy to become President of the United States. In the weeks after he became the presumptive Republican nominee, The Chronicle of Higher Education introduced the syllabus ‘Trump 101’ The Chronicle of Higher Education, 2016). Historians N.D.B Connolly and Keisha N. Blain found ‘Trump 101’ inadequate, 'a mock college syllabus… suffer[ing] from a number of egregious omissions and inaccuracies', failing to include 'contributions of scholars of color and address the critical subjects of Trump's racism, sexism, and xenophobia’. They assembled the ‘Trump Syllabus 2.0’ Connoly and Blain, 2016). Soon after, in response to a video in which Trump engaged in ‘an extremely lewd conversation about women’ with TV host Billy Bush, Laura Ciolkowski put together a ‘Rape Culture Syllabus’ (Ciolkowski, 2016).

August 2015 also saw the trending of #BlkWomenSyllabus and #SayHerNameSyllabus on Twitter. The hashtag #BlkWomenSyllabus began when the historian Daina Ramey Berry, PhD tweeted on August 11 "given #CharnesiaCorley time 4 #blkwomensyllabus...". Charnesia Corley, a 21-year-old black female Texas resident, was pulled over at a Texaco gas station on June 21, 2015, accused of running a stop sign. After the deputy allegedly smelled marijuana coming from Corley's car, the woman was forced to remove her clothing, bend over and later was held face down to the ground as police officers probed her vagina while forcing her legs open. #SayHerName is an activist movement that strives to end brutality and anti-Black violence of Black women and girls by the police. The #SayHerName movement is designed to acknowledge the ways in which police brutality disproportionally affect Black women, including Black girls, queer Black women and trans Black women. #SayHerName, coined as a call to action in February 2015 by the Africa American Policy Forum, was created alongside #BlackLivesMatter, which was created as a response to the acquittal of George Zimmerman in the fatal shooting of Black teen, Trayvon Martin. #SayHerName gained attention following the death of Sandra Bland, a Black woman found dead in custody of police, in July 2015.

An article about the #blackwomensyllabus:
https://www.essence.com/news/thank-blkwomensyllabus-ultimate-reading-list-empower-black-women/

‘Trump 101’, The Chronicle of Higher Education:
https://www.chronicle.com/article/Trump-Syllabus/236824

Trump Syllabus 2.0
This course, assembled by historians N. D. B. Connolly and Keisha N. Blain, includes suggested readings and other resources from more than one hundred scholars in a variety of disciplines. The course explores Donald Trump’s rise as a product of the American lineage of racism, sexism, nativism, and imperialism. 
https://www.publicbooks.org/trump-syllabus-2-0/

Here is a collection of suggested assignments to accompany Trump Syllabus 2.0 from the website of the African American Intellectual History Society. The contributing faculty member’s name is included:
https://www.aaihs.org/resources/trump-2-0-assignments/

‘Rape Culture Syllabus’, by Laura Ciolkowski 
https://www.publicbooks.org/rape-culture-syllabus/

In April 2016, members of the Standing Rock Sioux tribe established the Sacred Stone Camp and started the protest against The Dakota Access Pipeline, whose construction threatened the only water supply at the Standing Rock Reservation. The protest at the pipeline site became the largest gathering of native Americans over the past 100 years and earned significant international support for their ReZpect our Water campaign. As the struggle between protestors and armed forces unfolded, a group of indigenous scholars, activists and settler / PoC supporters, gathered under the name The NYC Stands for Standing Rock Committee, put together the #StandingRockSyllabus (NYC Stands for Standing Rock Committee, 2016).

NYC Stands with Standing Rock Collective. 2016. “#StandingRockSyllabus.” https://nycstandswithstandingrock.wordpress.com/standingrocksyllabus/.

PDF version of the #StandingRockSyllabus including all readings (80MB):
https://nycstandswithstandingrock.files.wordpress.com/2016/10/standingrocksyllabus7.pdf

The list of online syllabi created in response to political struggles has continued to grow, presently including many more examples, such as: 

All Monuments Must Fall Syllabus 
https://monumentsmustfall.wordpress.com/

#BLMSyllabus 
http://www.blacklivesmattersyllabus.com/

#BlackIslamSyllabus 
https://docs.google.com/document/d/1avhgPrW30AFjegzV9X5aPqkZUA3uGd0-BZr9_zhArtQ/edit#

#CharlestonSyllabus
#CharlestonSyllabus (Charleston Syllabus), is a Twitter movement and crowdsourced syllabus using the hashtag #CharlestonSyllabus to compile a list of reading recommendations relating to the history of racial violence in the United States. It was created in response to the race-motivated violence in Charleston, South Carolina on the evening of June 17, 2015, when Dylann Roof opened fire during a Bible study session at Emanuel African Methodist Episcopal Church, killing 9 people. The #CharlestonSyllabus campaign was the brainchild of Chad Williams, Associate Professor of African and Afro-American Studies at Brandeis University.

The book:
https://ugapress.org/book/9780820349572/charleston-syllabus/

A collated list:
The following list was compiled and organized by AAIHS (African American Intellectual History Society) blogger Keisha N. Blain, with the assistance of Melissa Morrone, Ryan P. Randall and Cecily Walker:
https://www.aaihs.org/resources/charlestonsyllabus/

#ColinKaepernickSyllabus 
On September 4, Rebecca Martinez tweeted Louis Moore and David J. Leonard, suggesting the creation of Colin Kaepernick Syllabus. Soon, we, along with  Bijan C. Bayne, Sarah J. Jackson, and many others began the work of creating a syllabus to hopefully elevate and empower the conversations that Colin Kaepernick started when he decided to sit down in protest during an August 26, 2016 preseason game. 
https://www.newblackmaninexile.net/2016/09/colinkaepernicksyllabus.html

#ImmigrationSyllabus 
Essential topics, readings, and multimedia that provide historical context to current debates
over immigration reform, integration, and citizenship. Created by immigration historians affiliated with the Immigration History Research Center and the Immigration and Ethnic History Society, January 26, 2017. The syllabus follows a chronological overview of U.S. immigration history, but it also includes thematic weeks that cover salient issues in political discourse today such as xenophobia, deportation policy, and border policing.
https://drive.google.com/file/d/0B1eIDteoJgugVGRkcTRyb3RnRnc/edit

Puerto Rico Syllabus (#PRSyllabus)
This syllabus provides a list of resources for teaching and learning about the current economic crisis in Puerto Rico. Our goal is to contribute to the ongoing public dialogue and rising social activism regarding the debt crisis by providing historical and sociological tools with which to assess its roots and its repercussions.  
https://puertoricosyllabus.com/

Syllabus for White People to Educate Themselves
By Dismantling Racism Works (dRworks). Created in response to the election of Donald Trump, 2017.
http://www.dismantlingracism.org/uploads/4/3/5/7/43579015/syllabus_for_white_people.pdf

Syllabus: Women and Gender Non-conforming People Writing about Tech 
https://docs.google.com/document/d/1Qx8JDqfuXoHwk41PZYWrZu3mmCsV05Fe09AtJ9ozw/edit


#WakandaSyllabus 
Introduction to the #WakandaSyllabus, by Dr. Walter Greason
https://www.aaihs.org/introduction-to-the-wakanda-syllabus/

What To Do Instead of Calling the Police. A Guide, A Syllabus, A Conversation, A Process
By Aaron Rose
https://www.aaronxrose.com/blog/alternatives-to-police

#YourBaltimoreSyllabus 
On April 12, 2015, Baltimore Police Department officers arrested Freddie Gray, a 25-year-old African American resident of Baltimore, Maryland, who died in police custody on April 19, 2015, a week after his arrest. Protests were organized after Gray's death became public knowledge, amid the police department's continuing inability to adequately or consistently explain the events following the arrest and the injuries. 
https://docs.google.com/document/d/1B_oyOyu_tAwOVq5MY1oJL3orN6ps04O82JxWxnkGpho/preview

